/***************************************************************************
 *   Copyright (C) 2020 Cyril Rossi <cyril.rossi@enioka.com>               *
 *   Copyright (C) 2021 Sergey V Turchin <zerg@altlinux.org>               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
 ***************************************************************************/

#include "componentchooserdata.h"

#include "componentchooseraudioplayer.h"
#include "componentchooservideoplayer.h"
#include "componentchooserimageviewer.h"

ComponentChooserData::ComponentChooserData(QObject *parent, const QVariantList &args)
    : KCModuleData(parent, args)
    , m_audioPlayers(new ComponentChooserAudioPlayer(this))
    , m_videoPlayers(new ComponentChooserVideoPlayer(this))
    , m_imageViewers(new ComponentChooserImageViewer(this))
{
    load();
}

void ComponentChooserData::load()
{
    m_audioPlayers->load();
    m_videoPlayers->load();
    m_imageViewers->load();
}

void ComponentChooserData::save()
{
    m_audioPlayers->save();
    m_videoPlayers->save();
    m_imageViewers->save();
}

void ComponentChooserData::defaults()
{
    m_audioPlayers->defaults();
    m_videoPlayers->defaults();
    m_imageViewers->defaults();
}

bool ComponentChooserData::isDefaults() const
{
    return m_audioPlayers->isDefaults() && m_videoPlayers->isDefaults() && m_imageViewers->isDefaults();
}

bool ComponentChooserData::isSaveNeeded() const
{
    return m_audioPlayers->isSaveNeeded() || m_videoPlayers->isSaveNeeded() || m_imageViewers->isSaveNeeded();
}

ComponentChooser *ComponentChooserData::audioPlayers() const
{
    return m_audioPlayers;
}

ComponentChooser *ComponentChooserData::videoPlayers() const
{
    return m_videoPlayers;
}

ComponentChooser *ComponentChooserData::imageViewers() const
{
    return m_imageViewers;
}
